// -------------------------------------------------------------------------------- 
//!  @file  main.c                                                                  
//!  メイン処理のソースファイル                                                     
//                                                                                  
//   Copyright (C) 2023 lsluk, All rights reserved.                                 
//   http://vdmgr.g2.xrea.com/index.html                                            
// -------------------------------------------------------------------------------- 
#include <stdio.h>
#include <string.h>
#include <pico/stdlib.h>
#include <hardware/adc.h>
#include "config.h"
#include "vga.h"
#include "ngplcd.h"

//! ADC 閾値
static uint16_t						m_adcThreshold[]={
										800,			// 0
										1300,			// 1
										1600,			// 2
										1900,			// 3
										2100,			// 4
										2400,			// 5
										2580			// 6
									} ;


// -------------------------------------------------------------------------------- 
//!  ディプスイッチから色を取得                                                     
//!                                                                                 
//!  @return 色                                                                     
// -------------------------------------------------------------------------------- 
static uint8_t RAMFUNC getColor( void )
{
	uint16_t	value ;
	int			index ;


	value = adc_read() ;

	for(index=0; index<sizeof( m_adcThreshold )/sizeof( m_adcThreshold[0] ); index++) {
		if( value < m_adcThreshold[index] ) {
			return (uint8_t )index ;
		}
	}

	return 0 ;
}


// -------------------------------------------------------------------------------- 
//!  メイン処理                                                                     
//!                                                                                 
//!  @param [in] argc  引数の数                                                     
//!  @param [in] argv  引数                                                         
//!  @return           常に０                                                       
// -------------------------------------------------------------------------------- 
int main(int argc, char *argv[])
{
//	setup_default_uart() ;

	adc_init() ;
	adc_gpio_init( 28 ) ;
	adc_select_input( 2 ) ;

	vga_init() ;
	ngplcd_init() ;

	vga_start() ;
	ngplcd_start() ;

	while( 1 ) {
		ngplcd_waitVSync() ;

		ngplcd_setColor( getColor() ) ;
	}

	return 0 ;
}
