// -------------------------------------------------------------------------------- 
//!  @file  vga.h                                                                   
//!  VGA ヘッダファイル                                                             
//                                                                                  
//   Copyright (C) 2021 lsluk, All rights reserved.                                 
//   http://vdmgr.g2.xrea.com/index.html                                            
// -------------------------------------------------------------------------------- 
#ifndef __DRIVER__VGA_H__INCLUDED__
#define __DRIVER__VGA_H__INCLUDED__


#include "config.h"
#include "hardware/dma.h"

//! VGA 関数
#define VGAFUNC						__attribute__ ((section(".data.vga_funcs")))


	enum {
		VGA_WIDTH					=	640,						//!< 水平解像度
		VGA_HEIGHT					=	480,						//!< 垂直解像度
		VGA_IMAGE_WIDTH				=	640,						//!< 画像幅
		VGA_IMAGE_HEIGHT			=	240							//!< 画像高さ
	} ;

	//! ラインバッファ
	typedef struct {
		//! ページ
		struct {
			uint16_t				data[VGA_IMAGE_WIDTH] ;			//!< データ
		} page[2] ;
	} VGALINEBUFF ;

	//! VGA 情報
	typedef struct {
		uint16_t					color ;							//!< 背景色
		uint16_t					dispLine ;						//!< 表示行
		volatile uint8_t			drawLine ;						//!< 描画行
		volatile uint8_t			drawCount ;						//!< 描画端数カウンタ
		dma_channel_config			dmaConfigPixel ;				//!< ピクセル転送用 DMA チャンネルコンフィグ
		dma_channel_config			dmaConfigData ;					//!< データ転送用 DMA チャンネルコンフィグ
		VGALINEBUFF					lineBuff ;						//!< ラインバッファ
	} VGAINFO ;


extern VGAINFO						g_vgaInfo ;						//!< VGA 情報


extern void         vga_init( void ) ;
extern void         vga_start( void ) ;
extern void VGAFUNC vga_waitVSync( void ) ;


#endif//__DRIVER__VGA_H__INCLUDED__
